@@ -405,8 +405,9 @@ func (screen *UnixScreen) Clear() {
 }
 
 // Returns the rendered line, plus how many information carrying cells went into
-// it (see headerLength inside of this function).
+// it
 func renderLine(row []Cell) (string, int) {
+	// Strip trailing whitespace
 	lastSignificantCellIndex := len(row) - 1
 	for ; lastSignificantCellIndex >= 0; lastSignificantCellIndex-- {
 		lastCell := row[lastSignificantCellIndex]
@@ -416,11 +417,6 @@ func renderLine(row []Cell) (string, int) {
 	}
 	row = row[0 : lastSignificantCellIndex+1]
 
-	if lastSignificantCellIndex < 0 {
-		// The entire line is whitespace, no need to render it
-		return "", 0
-	}
-
 	var builder strings.Builder
 
 	// Set initial line style to normal
